#if !defined  HAVE_PARENWORDS_H__
#define       HAVE_PARENWORDS_H__

#include "fxttypes.h"
#include "bits/bitsperlong.h"
#include "bits/bitcombcolex.h"  // first_comb()
#include "bits/bitlow.h"  // lowest_bit(), lowest_block()


inline bool is_parenword(ulong x)
// Binary words < 16, those that are valid
//  'paren words' are marked with 'P':
//  .... P   [empty string]
//  ...1 P   ()
//  ..1.
//  ..11 P   (())
//  .1..
//  .1.1 P   ()()
//  .11.
//  .111 P   ((()))
//  1...
//  1..1
//  1.1.
//  1.11 P   (()())
//  11..
//  11.1 P   ()(())
//  111.
//  1111 P   (((())))
{
    int s = 0;
    for (ulong j=0; x!=0; ++j)
    {
        s += ( x&1 ? +1 : -1 );
        if ( s<0 )  break;  // invalid word
        x >>= 1;
    }
    return  (s>=0);
}
// -------------------------


inline void parenword2str(ulong x, char *str)
// Binary words < 32 that are valid
//  'paren words' together with paren-string:
//  .....   [empty string]
//  ....1   ()
//  ...11   (())
//  ..1.1   ()()
//  ..111   ((()))
//  .1.11   (()())
//  .11.1   ()(())
//  .1111   (((())))
//  1..11   (())()
//  1.1.1   ()()()
//  1.111   ((()()))
//  11.11   (()(()))
//  111.1   ()((()))
//  11111   ((((()))))
// Note 1: lower bits in word (right end) correspond
//         to the begin of string (left end).
// Note 2: Word is extended with zeros (to the left) when necessary,
//         so the length of str must be >= 1 + 2*(number of set bits)
{
    int s = 0;
    ulong j = 0;
    for (j=0; x!=0; ++j)
    {
        s += ( x&1 ? +1 : -1 );
        // if ( s<0 )  {"Invalid word"}
        str[j] = ")("[x&1];
        x >>= 1;
    }
    while ( s-- > 0 )  str[j++] = ')';  // finish string
    str[j] = 0;  // terminate string
}
// -------------------------


inline ulong first_parenword(ulong n)
// Return least binary word corresponding to n pairs of parens.
{
    return first_comb(n);
}
// -------------------------


inline ulong last_parenword(ulong n)
// Return biggest binary word corresponding to n pairs of parens.
{
    ulong x = 1UL << (2*n-2),  s = 2;
    do
    {
        x |= (x>>s);  s <<= 1;
        x |= (x>>s);  s <<= 1;
        x |= (x>>s);  s <<= 1;
    }
    while ( s < BITS_PER_LONG );
    return x;

//    ulong x = 0,  s = 1;
//    while ( n-- ) { x |= s; s<<=2; }
//    return x;
}
// -------------------------


inline ulong next_parenword(ulong x)
// Next (colex order) binary word that is a paren word.
// With n=4 and starting with first_parenword(n)
//  one gets the following sequence:
//  .....1111   (((())))
//  ....1.111   ((()()))
//  ....11.11   (()(()))
//  ....111.1   ()((()))
//  ...1..111   ((())())
//  ...1.1.11   (()()())
//  ...1.11.1   ()(()())
//  ...11..11   (())(())
//  ...11.1.1   ()()(())
//  ..1...111   ((()))()
//  ..1..1.11   (()())()
//  ..1..11.1   ()(())()
//  ..1.1..11   (())()()
//  ..1.1.1.1   ()()()()
//  .........    [zero]
{
    ulong b = lowest_block(x);
    if ( b!=1 )  // split off highest bit of lowest block:
    {
        ++b;
        b ^= (b>>1);
        x ^= b;
    }
    else // Gather all low "01"s and split lowest nontrival block:
    {
        if ( 0==(x & (x>>1)) )  return 0;
        ulong w = 0;  // word where the bits are assembled
        ulong s = 0;  // shift for lowest block
        ulong b = 1;  // == lowest_bit(x)
        do
        {
            x ^= b;
            w <<= 1;
            w |= 1;
            ++s;
            b = lowest_bit(x);
        }
        while ( 0==(x&(b<<1)) );

        ulong z = x ^ (x+b);  // lowest block
        x ^= z;
        z &= (z>>1);
        z &= (z>>1);
        w ^= (z>>s);
        x |= w;
    }
    return x;
}
// -------------------------



#endif  // !defined HAVE_PARENWORDS_H__
