#if !defined HAVE_CYCLIC_PERM_H__
#define      HAVE_CYCLIC_PERM_H__


#include "aux0/swap.h"
#include "comb/mixedradix-gray.h"
#include "perm/perminvert.h"  // make_inverse()

#include "fxttypes.h"


class cyclic_perm
// Cyclic permutations in minimal change order.
// CAT algorithm based on mixed radix Gray code
//   for the factorial number system.
{
public:
    mixedradix_gray *mrg_;
    ulong n_;   // number of elements to permute
    ulong *ix_;  // current permutation (of {0, 1, ..., n-1})
    ulong *x_;  // inverse permutation
    ulong ct_;

public:
    cyclic_perm(ulong n)
        : n_(n)
    {
        ix_ = new ulong[n_];
        x_ = new ulong[n_];
        for (ulong k=0; k<n_-1; ++k)  x_[k] = n_-1-k;  // factorial base
        mrg_ = new mixedradix_gray(x_, n_-2);
        first();
    }

    ~cyclic_perm()
    {
        delete [] ix_;
        delete [] x_;
        delete mrg_;
    }

    void setup()
    {
        const ulong *fc = mrg_->data();
        for (ulong k=0; k<n_; ++k)  ix_[k] = k;

        for (ulong k=n_-1; k>1; --k)
        {
            ulong z = n_-3-(k-2); // 0, ..., n-3
            ulong i = fc[z];
            swap2(ix_[k], ix_[i]);
        }
        if ( n_>1 )  swap2(ix_[0], ix_[1]);

        make_inverse(ix_, x_, n_);
    }

    void first()
    {
        mrg_->first();
        setup();
        ct_ = 0;
    }

    ulong next()
    {
        if ( false == mrg_->next() )  { first(); return 0; }
        ulong j = mrg_->pos();

        if ( j && (x_[0]==n_-1) )  // once in 2*n cases
        {
            setup();  // work proportional n
            // only 3 elements are interchanged
        }
        else  // easy case
        {
            int d = mrg_->dir();
            ulong x2 = (mrg_->data())[j];
            ulong x1 = x2 - d,  x3 = n_-1;
            ulong i1 = x_[x1], i2 = x_[x2], i3 = x_[x3];

            swap2(x_[x1], x_[x2]);
            swap2(x_[x1], x_[x3]);
            swap2(ix_[i1], ix_[i2]);
            swap2(ix_[i2], ix_[i3]);
        }

        return  ++ct_;
    }

    ulong current()  const  { return ct_; }
    const ulong *data()  const  { return x_; }
    const ulong *invdata()  const  { return ix_; }
};
// -------------------------


#endif  // !defined HAVE_CYCLIC_PERM_H__
